pub struct ProgressBar { /* private fields */ }Expand description
Represents a custom progress bar for displaying flooding progress.
This progress bar includes styling with green coloring and additional information such as remaining time.
Implementations